changeset 18248:abe81a5bee85 draft

(svn r23084) -Codechange: get rid of a redundant variable
author rubidium <rubidium@openttd.org>
date Thu, 03 Nov 2011 22:49:03 +0000
parents 973050b62813
children bc05d52fdf23
files src/clear_cmd.cpp src/landscape.cpp src/misc.cpp src/saveload/afterload.cpp src/saveload/oldloader_sl.cpp src/settings_type.h src/table/gameopt_settings.ini src/table/settings.ini
diffstat 8 files changed, 15 insertions(+), 22 deletions(-) [+]
line wrap: on
line diff
--- a/src/clear_cmd.cpp
+++ b/src/clear_cmd.cpp
@@ -361,11 +361,6 @@
 	return;
 }
 
-void InitializeClearLand()
-{
-	_settings_game.game_creation.snow_line = _settings_game.game_creation.snow_line_height * TILE_HEIGHT;
-}
-
 static CommandCost TerraformTile_Clear(TileIndex tile, DoCommandFlag flags, uint z_new, Slope tileh_new)
 {
 	return DoCommand(tile, 0, 0, flags, CMD_LANDSCAPE_CLEAR);
--- a/src/misc.cpp
+++ b/src/misc.cpp
@@ -35,7 +35,6 @@
 void InitializeSound();
 void InitializeMusic();
 void InitializeVehicles();
-void InitializeClearLand();
 void InitializeRailGui();
 void InitializeRoadGui();
 void InitializeAirportGui();
@@ -80,7 +79,6 @@
 
 	InitNewsItemStructs();
 	InitializeLandscape();
-	InitializeClearLand();
 	InitializeRailGui();
 	InitializeRoadGui();
 	InitializeAirportGui();
--- a/src/saveload/afterload.cpp
+++ b/src/saveload/afterload.cpp
@@ -2648,6 +2648,11 @@
 		}
 	}
 
+	/* This triggers only when old snow_lines were copied into the snow_line_height. */
+	if (IsSavegameVersionBefore(164) && _settings_game.game_creation.snow_line_height >= MIN_SNOWLINE_HEIGHT * TILE_HEIGHT) {
+		_settings_game.game_creation.snow_line_height /= TILE_HEIGHT;
+	}
+
 	/* When any NewGRF has been changed the availability of some vehicles might
 	 * have been changed too. e->company_avail must be set to 0 in that case
 	 * which is done by StartupEngines(). */
--- a/src/saveload/oldloader_sl.cpp
+++ b/src/saveload/oldloader_sl.cpp
@@ -1724,7 +1724,7 @@
 	OCL_VAR ( OC_TTD | OC_UINT8,    1, &_trees_tick_ctr ),
 
 	OCL_CNULL( OC_TTD, 1 ),               ///< Custom vehicle types yes/no, no longer used
-	OCL_VAR ( OC_TTD | OC_UINT8,    1, &_settings_game.game_creation.snow_line ),
+	OCL_VAR ( OC_TTD | OC_UINT8,    1, &_settings_game.game_creation.snow_line_height ),
 
 	OCL_CNULL( OC_TTD, 32 ),              ///< new_industry_randtable, no longer used (because of new design)
 	OCL_CNULL( OC_TTD, 36 ),              ///< cargo-stuff
--- a/src/settings_type.h
+++ b/src/settings_type.h
@@ -216,7 +216,6 @@
 	byte   se_flat_world_height;             ///< land height a flat world gets in SE
 	byte   town_name;                        ///< the town name generator used for town names
 	byte   landscape;                        ///< the landscape we're currently in
-	byte   snow_line;                        ///< the snowline level in this game
 	byte   water_borders;                    ///< bitset of the borders that are water
 	uint16 custom_town_number;               ///< manually entered number of towns
 	byte   variety;                          ///< variety level applied to TGP
--- a/src/table/gameopt_settings.ini
+++ b/src/table/gameopt_settings.ini
@@ -132,7 +132,7 @@
 
 [SDT_VAR]
 base     = GameSettings
-var      = game_creation.snow_line
+var      = game_creation.snow_line_height
 type     = SLE_UINT8
 def      = DEF_SNOWLINE_HEIGHT * TILE_HEIGHT
 min      = MIN_SNOWLINE_HEIGHT * TILE_HEIGHT
--- a/src/table/settings.ini
+++ b/src/table/settings.ini
@@ -330,15 +330,11 @@
 full     = _climates
 load     = ConvertLandscape
 
-[SDT_VAR]
-base     = GameSettings
-var      = game_creation.snow_line
-type     = SLE_UINT8
+; Snow line (or snow_line_height * TILE_HEIGHT)
+[SDT_NULL]
+length   = SLE_UINT8
 from     = 97
-guiflags = SGF_NO_NETWORK
-def      = DEF_SNOWLINE_HEIGHT * TILE_HEIGHT
-min      = MIN_SNOWLINE_HEIGHT * TILE_HEIGHT
-max      = MAX_SNOWLINE_HEIGHT * TILE_HEIGHT
+to       = 163
 
 [SDT_OMANY]
 base     = GameSettings
--- a/src/landscape.cpp
+++ b/src/landscape.cpp
@@ -79,7 +79,7 @@
 /**
  * Description of the snow line throughout the year.
  *
  * If it is \c NULL, a static snowline height is used, as set by \c _settings_game.game_creation.snow_line.
  * Otherwise it points to a table loaded from a newGRF file that describes the variable snowline.
  * @ingroup SnowLineGroup
  * @see GetSnowLine() GameCreationSettings
@@ -561,7 +561,7 @@
  */
 byte GetSnowLine()
 {
-	if (_snow_line == NULL) return _settings_game.game_creation.snow_line;
+	if (_snow_line == NULL) return _settings_game.game_creation.snow_line_height * TILE_HEIGHT;
 
 	YearMonthDay ymd;
 	ConvertDateToYMD(_date, &ymd);
@@ -575,7 +575,7 @@
  */
 byte HighestSnowLine()
 {
-	return _snow_line == NULL ? _settings_game.game_creation.snow_line : _snow_line->highest_value;
+	return _snow_line == NULL ? _settings_game.game_creation.snow_line_height * TILE_HEIGHT : _snow_line->highest_value;
 }
 
 /**
@@ -585,7 +585,7 @@
  */
 byte LowestSnowLine()
 {
-	return _snow_line == NULL ? _settings_game.game_creation.snow_line : _snow_line->lowest_value;
+	return _snow_line == NULL ? _settings_game.game_creation.snow_line_height * TILE_HEIGHT : _snow_line->lowest_value;
 }
 
 /**
@@ -79,7 +79,7 @@
  * Description of the snow line throughout the year.
  *
- * If it is \c NULL, a static snowline height is used, as set by \c _settings_game.game_creation.snow_line.
+ * If it is \c NULL, a static snowline height is used, as set by \c _settings_game.game_creation.snow_line_height.
  * Otherwise it points to a table loaded from a newGRF file that describes the variable snowline.
  * @ingroup SnowLineGroup